<!DOCTYPE TS><TS>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Level %1</source>
        <translation>Niveau %1</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation>Pas d&apos;affiche</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Valider</translation>
    </message>
</context>
<context>
    <name>FileAssocDialog</name>
    <message>
        <source>Please enter the new extension:</source>
        <translation>Entrez une nouvelle extension:</translation>
    </message>
    <message>
        <source>Create new extension</source>
        <translation>Créer une nouvelle extension</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Valider</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Suppr.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds videos</source>
        <translation>Répertoire qui contient les vidéos</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo only needs to have read permission to the directory.</source>
        <translation>Ce répertoire doit exister et l&apos;utilisateur de MythVideo doit avoir la permission en lecture sur ce répertoire.</translation>
    </message>
    <message>
        <source>Starting Parental Level</source>
        <translation>Niveau parental initial</translation>
    </message>
    <message>
        <source>4 - Highest</source>
        <translation>4 - Laxiste</translation>
    </message>
    <message>
        <source>1 - Lowest</source>
        <translation>1 - Sévère</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
        <translation>C&apos;est le niveau à partir duquel MythVideo démarre. Toutes les vidéos avec un niveau inférieur ou égal à la valeur seront affiché dans la liste. Afin d&apos;empêcher le changement du niveau par défaut, le code parental doit être saisi !</translation>
    </message>
    <message>
        <source>Parental Control PIN</source>
        <translation>Code de contrôle parental</translation>
    </message>
    <message>
        <source>If set, you will not be able to return to this screen and reset the Parental PIN without first entering the current PIN. You have been warned.</source>
        <translation>Si coché, vous ne pourrez pas retourner à cette écran sans devoir saisir le code parental.</translation>
    </message>
    <message>
        <source>Show Unknown File Types</source>
        <translation>Afficher les fichiers de type inconnu</translation>
    </message>
    <message>
        <source>If set, all files below the Myth Video directory will be displayed unless their extension is explicitly set to be ignored. </source>
        <translation>Si coché, tous les fichiers du répertoire de MythVideo seront affichées sauf les fichiers pour lesquels les extensions sont explicitement ignorées.</translation>
    </message>
    <message>
        <source>Video List browses files</source>
        <translation>Afficher tous les fichiers</translation>
    </message>
    <message>
        <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation>Si coché, l&apos;écran &apos;Liste des vidéos&apos; affichera tous les fichiers du répertoire MythVideo même s&apos;ils n&apos;ont pas été recherchés.</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Configuration générale</translation>
    </message>
    <message>
        <source>Player Settings</source>
        <translation>Configuration du lecteur</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation>Code parental:</translation>
    </message>
    <message>
        <source>Searching for video files</source>
        <translation>Rechercher les fichiers</translation>
    </message>
    <message>
        <source>Updating video database</source>
        <translation>Mise à jour de la BDD vidéo</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation>Pas d&apos;affiche</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>NR</source>
        <translation>NR</translation>
    </message>
    <message>
        <source>Unknown Rating</source>
        <translation>Tout public</translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation>Lecteur par défaut</translation>
    </message>
    <message>
        <source>Newly scanned files are browsable by default</source>
        <translation>Les fichiers nouvellement analysés sont affichés</translation>
    </message>
    <message>
        <source>If set, newly scanned files in the Video Manager will be marked as browsable and will appear in the &apos;Browse&apos; menu.</source>
        <translation>Si coché, les fichiers nouvellement analysés dans le gestionnaire de vidéos seront automatiquement marqué comme affichable et apparaissent dans le menu &apos;Naviguer&apos;</translation>
    </message>
    <message>
        <source>New category</source>
        <translation>Nouvelle Catégorie</translation>
    </message>
    <message>
        <source>This PIN is used to control the current Parental Level. If you want to use this feature, then setting the value to all numbers will make your life much easier.</source>
        <translation>Ce code est utilisé pour le contrôle du niveau du code parental. Si vous désirez utiliser cette fonctionnalité, nous vous conseillons d&apos;utiliser des valeurs numériques afin de vous rendre la vie plus facile.</translation>
    </message>
    <message>
        <source>Command to search for movie listings</source>
        <translation>Commande de recherche de vidéo</translation>
    </message>
    <message>
        <source>This command must be executable by the user running MythVideo.</source>
        <translation>Cette commande est exécutée par l&apos;utilisateur exécutant MythVideo pour chercher le listing des vidéos.</translation>
    </message>
    <message>
        <source>Command to search for movie posters</source>
        <translation>Commande de recherche des affiches</translation>
    </message>
    <message>
        <source>Command to extract data for movies</source>
        <translation>Commande pour extraire les données des films</translation>
    </message>
    <message>
        <source>Directory that holds movie posters</source>
        <translation>Répertoire qui contient les affiches</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo needs to have read/write permission to the directory.</source>
        <translation>Ce répertoire doit exister et l&apos;utilisateur exécutant MythVideo doit avoir les droits de lecture/écriture sur celui-ci</translation>
    </message>
    <message>
        <source>Video Manager</source>
        <translation>Gestion Vidéo</translation>
    </message>
    <message>
        <source>Could not retrieve poster</source>
        <translation>impossible de trouver une affiche</translation>
    </message>
    <message>
        <source>A movie poster exists for this movie but Myth could not retrieve it within a reasonable amount of time.
</source>
        <translation>Un poster existe pour cette vidéo, mais mythtv ne peut pas la télécharger en un temps raisonnable</translation>
    </message>
    <message>
        <source>Default View</source>
        <translation>Vue par défaut</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galerie</translation>
    </message>
    <message>
        <source>Browser</source>
        <translation>Navigateur</translation>
    </message>
    <message>
        <source>Listings</source>
        <translation>Liste</translation>
    </message>
    <message>
        <source>Aggressive Parental Control</source>
        <translation>Contrôle Parental Agressif</translation>
    </message>
    <message>
        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos;.</source>
        <translation>cette commande est utilisée four tous le fichiers dont l&apos;extension n&apos;est explicitement définie. Vous pouvez aussi entrer le nom de l&apos;un des plugins de lecture tels que &apos;internal&apos;</translation>
    </message>
    <message>
        <source>Rows to display</source>
        <translation>Lignes à afficher</translation>
    </message>
    <message>
        <source>Columns to display</source>
        <translation>Colonnes à afficher</translation>
    </message>
    <message>
        <source>Show title below thumbnails</source>
        <translation>Afficher les titres près des miniatures</translation>
    </message>
    <message>
        <source>If set, the additional text will make the thumbnails smaller.</source>
        <translation>Si forcé, un texte supplémentaire sera affiché rendant les miniatures plus petites</translation>
    </message>
    <message>
        <source>Maintain aspect ratio of thumbnails</source>
        <translation>Maintient le ratio d&apos;aspect de la miniature</translation>
    </message>
    <message>
        <source>If set, the scaled thumbnails will maintain their original aspect ratio. If not set, they are scaled to match the size of the background icon.</source>
        <translation>Si forcé, l&apos;échelle des miniatures est maintenue avec le ratio d&apos;origine. Sinon, l&apos;échelle est redimensionnée avec d&apos;obtenir la taille de l&apos;icône d&apos;arrière plan du thème.</translation>
    </message>
    <message>
        <source>Video Gallery</source>
        <translation>Galerie Vidéo</translation>
    </message>
    <message>
        <source>The default view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
        <translation>La vue par défaut pour MythVideo. Les autres vues peuvent être atteintes à travers le menu popup accessible par la touche MENU</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Director:</source>
        <translation>Réal.:</translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>Année:</translation>
    </message>
    <message>
        <source>Rated:</source>
        <translation>Classé:</translation>
    </message>
    <message>
        <source>Parental Level:</source>
        <translation>Niveau parental:</translation>
    </message>
    <message>
        <source>Browsable:</source>
        <translation>Listé:</translation>
    </message>
    <message>
        <source>Runtime:</source>
        <translation>Durée:</translation>
    </message>
    <message>
        <source>Plot:</source>
        <translation>Résumé:</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>Fichier:</translation>
    </message>
    <message>
        <source>Cover File:</source>
        <translation>Affiche:</translation>
    </message>
    <message>
        <source>IMDB Num.:</source>
        <translation>N° allociné:</translation>
    </message>
    <message>
        <source>retrieving data...</source>
        <translation>Récupération des données...</translation>
    </message>
    <message>
        <source>[ looking for ]</source>
        <translation>[ recherche ]</translation>
    </message>
    <message>
        <source>Enter IMDB #</source>
        <translation>Saisir le N° allociné</translation>
    </message>
    <message>
        <source>loading...</source>
        <translation>Chargement...</translation>
    </message>
    <message>
        <source>No Videos Found</source>
        <translation>Aucune vidéo trouvée</translation>
    </message>
    <message>
        <source>Directed by</source>
        <translation>Réalisé par:</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>Fichier:</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>Lecteur:</translation>
    </message>
    <message>
        <source>MythVideo File Associations</source>
        <translation>Association de fichiers de MythVideo</translation>
    </message>
    <message>
        <source>Extension:</source>
        <translation>Extension:</translation>
    </message>
    <message>
        <source>Command:</source>
        <translation>Commande:</translation>
    </message>
    <message>
        <source>Use default player:</source>
        <translation>Lecteur par défaut:</translation>
    </message>
    <message>
        <source>Ignore:</source>
        <translation>Ignoré:</translation>
    </message>
    <message>
        <source>Edit Video Information</source>
        <translation>Éditer les informations de la vidéo</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <source>Parental Control:</source>
        <translation>Niveau parental:</translation>
    </message>
    <message>
        <source>File to Always Play Next:</source>
        <translation>Fichier à lire ensuite:</translation>
    </message>
    <message>
        <source>Include while Browsing:</source>
        <translation>Inclure dans la liste:</translation>
    </message>
    <message>
        <source>Cover Art:</source>
        <translation>Affiche:</translation>
    </message>
    <message>
        <source>/path/to/the/thing.jpg</source>
        <translation>/Chemin/d&apos;accès/à/l&apos;affiche.jpg</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>PL </source>
        <translation>PL </translation>
    </message>
    <message>
        <source>Unique Player Command:</source>
        <translation>Commande du lecteur:</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Catégorie</translation>
    </message>
    <message>
        <source>Filters video list</source>
        <translation>Liste de filtres vidéo</translation>
    </message>
    <message>
        <source>Category :</source>
        <translation>Catégorie:</translation>
    </message>
    <message>
        <source>Genre :</source>
        <translation>Genre:</translation>
    </message>
    <message>
        <source>Country :</source>
        <translation>Pays:</translation>
    </message>
    <message>
        <source>Year :</source>
        <translation>Année:</translation>
    </message>
    <message>
        <source>Runtime :</source>
        <translation>Durée:</translation>
    </message>
    <message>
        <source>User Rating :</source>
        <translation>Notation:</translation>
    </message>
    <message>
        <source>Browse :</source>
        <translation>Navigable:</translation>
    </message>
    <message>
        <source>Sort by :</source>
        <translation>Trier par:</translation>
    </message>
    <message>
        <source>Aucune video</source>
        <translation>Aucune vidéo</translation>
    </message>
    <message>
        <source>SELECT: Edit</source>
        <translation>Sélect: Éditer</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Parental</source>
        <translation>Niveau</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>parental</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Année</translation>
    </message>
    <message>
        <source>Runtime</source>
        <translation>Durée</translation>
    </message>
    <message>
        <source>User Rating</source>
        <translation>Notation</translation>
    </message>
    <message>
        <source>INFO - Action Menu</source>
        <translation>INFO - Menu Actions</translation>
    </message>
    <message>
        <source>Up/Down, Page Up/Down: Browse   MENU: Options   INFO: Action Menu</source>
        <translation>Haut/Bas, Page Haut/Bas: Naviguer   MENU: Options   INFO: Menu Action</translation>
    </message>
    <message>
        <source>Play File After This:</source>
        <translation>Jouer le fichier après ceci:</translation>
    </message>
</context>
<context>
    <name>VideoBrowser</name>
    <message>
        <source>%1 of %2</source>
        <translation>%1 sur %2</translation>
    </message>
    <message>
        <source>No Videos</source>
        <translation>Pas de vidéos</translation>
    </message>
    <message>
        <source>No rating available.</source>
        <translation>Pas de note disponible.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutes</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Regarder cette vidéo</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Voir l&apos;affiche</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Filtrer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>VideoDialog</name>
    <message>
        <source>Switch to Browse View</source>
        <translation>Mode navigation</translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation>Mode gallerie</translation>
    </message>
    <message>
        <source>Switch to List View</source>
        <translation>Mode liste</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation>Choix action</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation>Code parental:</translation>
    </message>
</context>
<context>
    <name>VideoFilterDialog</name>
    <message>
        <source>Result of this filter : %1 video(s)</source>
        <translation>Résultats de ce filtre : %1 vidéo(s)</translation>
    </message>
    <message>
        <source>Result of this filter : No Videos</source>
        <translation>Résultats de ce filtre : Aucune vidéo</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutes</translation>
    </message>
    <message>
        <source>All</source>
        <translation>tous</translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation>Filtre par défaut</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Valider</translation>
    </message>
</context>
<context>
    <name>VideoGallery</name>
    <message>
        <source>Watch This Video</source>
        <translation>Regarder cette vidéo</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Voir le résumé complet</translation>
    </message>
    <message>
        <source>View Details</source>
        <translation>Voir les détails</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Filtrage</translation>
    </message>
    <message>
        <source>Plain View</source>
        <translation>Vue plane</translation>
    </message>
    <message>
        <source>Folder View</source>
        <translation>Vue avec dossiers</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>VideoManager</name>
    <message>
        <source>Manually Enter IMDB #</source>
        <translation>Entrer le n° allociné</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutes</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation>Pas d&apos;affiche</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>NR</source>
        <translation>NR</translation>
    </message>
    <message>
        <source>delete failed</source>
        <translation>échec de l&apos;effacement</translation>
    </message>
    <message>
        <source>Select action:</source>
        <translation>Choix d&apos;action:</translation>
    </message>
    <message>
        <source>Edit Metadata</source>
        <translation>Édition des données</translation>
    </message>
    <message>
        <source>Search IMDB</source>
        <translation>Recherche allociné</translation>
    </message>
    <message>
        <source>Reset Metadata</source>
        <translation>Effacer les données</translation>
    </message>
    <message>
        <source>Toggle Browseable</source>
        <translation>Navigable O/N</translation>
    </message>
    <message>
        <source>Remove Video</source>
        <translation>Supprimer la vidéo</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Filtre d&apos;affichage</translation>
    </message>
    <message>
        <source>Delete this file?</source>
        <translation>Effacer ce fichier ?</translation>
    </message>
</context>
<context>
    <name>VideoSelected</name>
    <message>
        <source>No rating available.</source>
        <translation>Pas de note disponible.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutes</translation>
    </message>
</context>
<context>
    <name>VideoTree</name>
    <message>
        <source>No files found</source>
        <translation>Pas de fichier trouvé</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation>Code parental:</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation>Choix action</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Regarder Cette Vidéo</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Montrer l&apos;affiche</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Filtre d&apos;affichage</translation>
    </message>
    <message>
        <source>Switch to Browse View</source>
        <translation>Mode navigation</translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation>Mode gallerie</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
</TS>
